@@ -6,6 +6,7 @@ import tkinter as tk
 
 class InGameException(Exception):
     """Exception for InGame module"""
+
     pass
 
 class EventType:
@@ -70,6 +71,7 @@ class EventType:
 
         SHIFT_L = "SHIFT_L"
         SHIFT_R = "SHIFT_R"
+
 EventsType = EventType.Key
 
 class InGame:
@@ -101,7 +103,7 @@ class InGame:
             if not inspect.isfunction(func):
                 raise InGameException("Parameter 'func' must be a function.")
 
-            @wraps(func)
+            @wraps(wrapped=func)
             def wrapper() -> None:
                 self.events[type] = func
 
@@ -127,13 +129,20 @@ class InGame:
             raise InGameException(f"No event for {type.name}")
         func()
 
-    def clear_events(
+    def clear_all_events(
         self
     ) -> None:
         """Clears all registered events"""
 
         self.events = {}
 
+    def clear_event(
+        self,
+        event: EventsType
+    ) -> None:
+        self.events.pop(event, None)
+
+
 class Screen:
     """Application window"""
 
@@ -191,4 +200,4 @@ class Screen:
     ) -> None:
         """Quit the window"""
 
-        self.root.destroy()
\ No newline at end of file
+        self.root.destroy()
